==> node-red-contrib-chatbot-1.1.4.tgz: package/bin/nodes.js <==
module.exports = [
  {
    nodeFile: 'mc-configuration.html',
    nodeType: 'mc-configuration',
    notionUrl: 'https://www.notion.so/redbot/MC-Configuration-node-585cd33e293c40478a47635246742a27'
  },
  {
    nodeFile: 'chatbot-alexa-card.html',
    nodeType: 'chatbot-alexa-card',
    notionUrl: 'https://redbot.notion.site/Alexa-Card-node-fc89c43d79324c8da2f251e26f638246'
  },
  {
    nodeFile: 'mc-graphql.html',
    nodeType: 'mc-graphql',
    notionUrl: 'https://www.notion.so/redbot/MC-GraphQL-node-0dc75116dee9458486e1a4f09fc3f44b'
  },
  {
    notionUrl: 'https://www.notion.so/redbot/Generic-Template-node-1102a94bf9d445178dfb621fe3c91b58',
    nodeFile: 'chatbot-generic-template.html',
    nodeType: 'chatbot-generic-template'
  },
  {
    notionUrl: 'https://www.notion.so/redbot/Quick-Replies-node-200e9ae1a1fd459baa29c76d6a4025e2',
    nodeFile: 'chatbot-quick-replies.html',
    nodeType: 'chatbot-quick-replies'
  },
  {
    notionUrl: 'https://www.notion.so/redbot/Messenger-Menu-node-c5140a0ab4ae4345a2731f67b92c3e53',
    nodeFile: 'chatbot-messenger-menu.html',
    nodeType: 'chatbot-messenger-menu'
  },
  {
    notionUrl: 'https://www.notion.so/redbot/Messenger-Template-node-ac7d5049cbf64389a2ef6e7fe7f1c392',
    nodeFile: 'chatbot-messenger-template.html',
    nodeType: 'chatbot-messenger-template'
  },
  {
    notionUrl: 'https://www.notion.so/redbot/Document-node-c36fbd8a58574fd0bbf8b0eb04a7d4ae',
    nodeFile: 'chatbot-document.html',
    nodeType: 'chatbot-document'
  },
  {
    notionUrl: 'https://www.notion.so/redbot/Message-node-4ae98c5959704cd993a0cc602a17d68b',
    nodeFile: 'chatbot-message.html',
    nodeType: 'chatbot-message'
  },
  {
    notionUrl: 'https://www.notion.so/redbot/QR-Code-node-94a74e1e16da4c2bbb09a983424354ed',
    nodeFile: 'chatbot-qrcode.html',
    nodeType: 'chatbot-qrcode'
  },
  {
    notionUrl: 'https://www.notion.so/redbot/Rivescript-node-db8481a702b6491093f7ea53d765129e',
    nodeFile: 'chatbot-rivescript.html',
    nodeType: 'chatbot-rivescript'
  },
  {
    notionUrl: 'https://www.notion.so/redbot/Conversation-node-1d90a6e8dfc448d6865c88358c459de2',
    nodeFile: 'chatbot-conversation.html',
    nodeType: 'chatbot-conversation'
  },
  {
    notionUrl: 'https://www.notion.so/redbot/Analytics-node-58dbe17dd23144c6b3ec939a23676b27',
    nodeFile: 'chatbot-analytics.html',
    nodeType: 'chatbot-analytics'
  },
  {
    notionUrl: 'https://www.notion.so/redbot/Debug-node-d768699fac104d0580f14268afa1e53f',
    nodeFile: 'chatbot-debug.html',
    nodeType: 'chatbot-debug'
  },
  {
    notionUrl: 'https://www.notion.so/redbot/Parse-node-face8e9f6efc4369a9ea8527ecd81b1b',
    nodeFile: 'chatbot-parse.html',
    nodeType: 'chatbot-parse'
  },
  {
    notionUrl: 'https://www.notion.so/redbot/Request-node-df78ffeae16d40238f672fbc447ba69e',
    nodeFile: 'chatbot-request.html',
    nodeType: 'chatbot-request'
  },
  {
    notionUrl: 'https://www.notion.so/redbot/Video-node-b359c5ca72494ac6aa5cfff23b1d76fc',
    nodeFile: 'chatbot-video.html',
    nodeType: 'chatbot-video'
  },
  {
    notionUrl: 'https://www.notion.so/redbot/Audio-node-fab15f139525400f8719ff182238eb4c',
    nodeFile: 'chatbot-audio.html',
    nodeType: 'chatbot-audio'
  },
  {
    notionUrl: 'https://www.notion.so/redbot/Voice-node-dbd09f980ed5438e90eb8379ab15594c',
    nodeFile: 'chatbot-voice.html',
    nodeType: 'chatbot-voice'
  },
  {
    notionUrl: 'https://www.notion.so/redbot/Image-node-e4db571720f74584bfa97668c100db43',
    nodeFile: 'chatbot-image.html',
    nodeType: 'chatbot-image'
  },
  {
    notionUrl: 'https://www.notion.so/redbot/Language-node-f5566a5158ad462186414d41766e7056',
    nodeFile: 'chatbot-language.html',
    nodeType: 'chatbot-language'
  },
  {
    notionUrl: 'https://www.notion.so/redbot/Authorized-node-cc9655594def44648f6e02cbf17d9714',
    nodeFile: 'chatbot-authorized.html',
    nodeType: 'chatbot-authorized'
  },
  {
    notionUrl: 'https://www.notion.so/redbot/Log-node-58087595acec4d0593dd7f1375b092d5',
    nodeFile: 'chatbot-log.html',
    nodeType: 'chatbot-log'
  },
  {
    notionUrl: 'https://www.notion.so/redbot/Location-node-60e07c48313c4d0690c0e2ff96fa941f',
    nodeFile: 'chatbot-location.html',
    nodeType: 'chatbot-location'
  },
  {
    notionUrl: 'https://www.notion.so/redbot/Context-node-24a646bff58b4edfb249f1d27384230f',
    nodeFile: 'chatbot-context.html',
    nodeType: 'chatbot-context'
  },
  {
    notionUrl: 'https://www.notion.so/redbot/Telegram-Sticker-node-0e02d900e15e45b39eb4150941d7c9ea',
    nodeFile: 'chatbot-sticker.html',
    nodeType: 'chatbot-sticker'
  },
  {
    notionUrl: 'https://www.notion.so/redbot/Animation-node-5900586541c2444689d3789a7f9f1d77',
    nodeFile: 'chatbot-animation.html',
    nodeType: 'chatbot-animation'
  },
  {
    notionUrl: 'https://www.notion.so/redbot/Telegram-Menu-node-d7159ae828804a8784a639e6cdbdb95d',
    nodeFile: 'chatbot-telegram-menu.html',
    nodeType: 'chatbot-telegram-menu'
  },
  {
    notionUrl: 'https://www.notion.so/redbot/Waiting-node-a020cb205ea249b2a401bdcf8c93ce05',
    nodeFile: 'chatbot-waiting.html',
    nodeType: 'chatbot-waiting'
  },
  {
    notionUrl: 'https://www.notion.so/redbot/Slack-Receiver-node-0e93599cefc44ce7896d5444def135f2',
    nodeFile: 'chatbot-slack-receive.html',
    nodeType: 'chatbot-slack-node'
  },
  {
    notionUrl: 'https://www.notion.so/redbot/Telegram-Receiver-node-4132ce6c78dc4dbbab0fe9eb7e1c3c9b',
    nodeFile: 'chatbot-telegram-receive.html',
    nodeType: 'chatbot-telegram-node'
  },
  {
    notionUrl: 'https://www.notion.so/redbot/Facebook-Receiver-node-c942d43ddc4b4368abb8d00dde650bfa',
    nodeFile: 'chatbot-facebook-receive.html',
    nodeType: 'chatbot-facebook-node'
  },
  {
    notionUrl: 'https://www.notion.so/redbot/Alexa-Receiver-node-82b7744b70fa45e8b786fdd2feae1777',
    nodeFile: 'chatbot-alexa-receive.html',
    nodeType: 'chatbot-alexa-node'
  },
  {
    notionUrl: 'https://www.notion.so/redbot/Twilio-Receiver-node-a0fb82e714fb4674b29e24fa984ca992',
    nodeFile: 'chatbot-twilio-receive.html',
    nodeType: 'chatbot-twilio-node'
  },
  {
    notionUrl: 'https://www.notion.so/redbot/Microsoft-Teams-Receiver-node-7bc640d7770e4542a83de7c8ee0cc246',
    nodeFile: 'chatbot-msteams-receive.html',
    nodeType: 'chatbot-msteams-node'
  },
  {
    notionUrl: 'https://www.notion.so/redbot/Viber-Receiver-node-ae52e68a3aef4483b52b339caa08c62c',
    nodeFile: 'chatbot-viber-receive.html',
    nodeType: 'chatbot-viber-node'
  },
  {
    notionUrl: 'https://www.notion.so/redbot/Switch-node-017a464afeb84225bcb68f8c671808c5',
    nodeFile: 'chatbot-rules.html',
    nodeType: 'chatbot-rules'
  },
  {
    notionUrl: 'https://www.notion.so/redbot/Telegram-Inline-Query-node-ab8e6fd699d544fb852111146edc39db',
    nodeFile: 'chatbot-inline-query.html',
    nodeType: 'chatbot-inline-query'
  },
  {
    notionUrl: 'https://www.notion.so/redbot/Slack-Dialog-node-e620ae50b7ed44c2a24d6876534b3637',
    nodeFile: 'chatbot-dialog.html',
    nodeType: 'chatbot-dialog'
  },
  {
    notionUrl: 'https://www.notion.so/redbot/Rules-node-4113636f565d4ff4af08bc61a644206b',
    nodeFile: 'chatbot-rules.html',
    nodeType: 'chatbot-rules'
  },
  {
    notionUrl: 'https://www.notion.so/redbot/Dialogflow-node-84b9ea66d20743fd9cf45d3de5f17693',
    nodeFile: 'chatbot-dialogflow.html',
    nodeType: 'chatbot-dialogflow'
  },
  {
    notionUrl: 'https://www.notion.so/redbot/Dialogflow-token-node-3663be9a404e4e3a9f3022bb66fe8d1e',
    nodeFile: 'chatbot-dialogflow.html',
    nodeType: 'chatbot-dialogflow-token'
  },
  {
    notionUrl: 'https://www.notion.so/redbot/Invoice-node-15b9b0d320d04b55ad550610112f04dd',
    nodeFile: 'chatbot-invoice.html',
    nodeType: 'chatbot-invoice'
  },
  {
    notionUrl: 'https://www.notion.so/redbot/Telegram-Invoice-Shipping-node-60c4b7025cde40378e87e7c3113907ed',
    nodeFile: 'chatbot-invoice-shipping.html',
    nodeType: 'chatbot-invoice-shipping'
  },
  {
    notionUrl: 'https://www.notion.so/redbot/Context-node-24a646bff58b4edfb249f1d27384230f',
    nodeFile: 'chatbot-context-store.html',
    nodeType: 'chatbot-context-store'
  },
  {
    notionUrl: 'https://www.notion.so/redbot/Keyboard-node-0085af98bd2c4c169d4c7e579c7db316',
    nodeFile: 'chatbot-ask.html',
    nodeType: 'chatbot-ask'
  },
  {
    notionUrl: 'https://www.notion.so/redbot/Buttons-node-b8f3ea33948049cca7b94491061183f4',
    nodeFile: 'chatbot-inline-buttons.html',
    nodeType: 'chatbot-inline-buttons'
  },
  {
    notionUrl: 'https://www.notion.so/redbot/Extend-node-04668c7a415547bc9f34be57dd063db2',
    nodeFile: 'chatbot-extend.html',
    nodeType: 'chatbot-extend'
  },
  {
    notionUrl: 'https://www.notion.so/redbot/Messenger-Broadcast-node-79a3de9e5f6d4c3faf8561997092ab56',
    nodeFile: 'chatbot-broadcast.html',
    nodeType: 'chatbot-broadcast'
  },
  {
    notionUrl: 'https://www.notion.so/redbot/Support-table-6cfd957b91f642b5894a76e2b15feb05',
    nodeFile: 'chatbot-support-table.html',
    nodeType: 'chatbot-support-table'
  },
  {
    notionUrl: 'https://www.notion.so/redbot/Alexa-Receiver-node-82b7744b70fa45e8b786fdd2feae1777',
    nodeFile: 'chatbot-alexa-speech.html',
    nodeType: 'chatbot-alexa-speech'
  },
  {
    notionUrl: 'https://www.notion.so/redbot/Alexa-Directive-node-e1e54a8f8c24404f8cd2b01e91b695cf',
    nodeFile: 'chatbot-alexa-directive.html',
    nodeType: 'chatbot-alexa-directive'
  },
  {
    notionUrl: 'https://www.notion.so/redbot/Universal-Connector-node-4c24b378e02c491a90240309b9f349c1',
    nodeFile: 'chatbot-universal-receive.html',
    nodeType: 'chatbot-universal-receive'
  },
  {
    notionUrl: 'https://www.notion.so/redbot/Slack-Blocks-node-deb80b7ba4584671abf117b8772a694a',
    nodeFile: 'chatbot-slack-blocks.html',
    nodeType: 'chatbot-slack-blocks'
  },
  {
    notionUrl: 'https://www.notion.so/redbot/Params-node-d8b27db3949c475184923af913563833',
    nodeFile: 'chatbot-params.html',
    nodeType: 'chatbot-params'
  },
  {
    notionUrl: 'https://www.notion.so/redbot/NLPjs-Train-77f9e99250274f12b37b67fd3854f831',
    nodeFile: 'chatbot-nlp-train.html',
    nodeType: 'chatbot-nlpjs-train'
  },
  {
    notionUrl: 'https://www.notion.so/redbot/NLPjs-Entity-f73d1e0200804467b8f03e077584fb16',
    nodeFile: 'chatbot-nlp-entity.html',
    nodeType: 'chatbot-nlpjs-entity'
  },
  {
    notionUrl: 'https://www.notion.so/redbot/NLPjs-Intent-node-c91af0a6fde74dc5b575aa7230565ba8',
    nodeFile: 'chatbot-nlp-intent.html',
    nodeType: 'chatbot-nlpjs-intent'
  },
  {
    notionUrl: 'https://www.notion.so/redbot/NLPjs-Save-4f99d9bfe1ee4683acbee70c02eb24d2',
    nodeFile: 'chatbot-nlp-save.html',
    nodeType: 'chatbot-nlpjs-save'
  },
  {
    notionUrl: 'https://www.notion.so/redbot/NLPjs-Load-fc80ea9420fe492389109c610ee7f812',
    nodeFile: 'chatbot-nlp-load.html',
    nodeType: 'chatbot-nlpjs-load'
  },
  {
    notionUrl: 'https://www.notion.so/redbot/NLPjs-Process-bbc3deb2d39a4b338fc6515eee337cd4',
    nodeFile: 'chatbot-nlp.html',
    nodeType: 'chatbot-nlpjs'
  },
  {
    notionUrl: 'https://www.notion.so/redbot/MC-User-Payload-dc8260a96abb430c856bfc2deb388238',
    nodeFile: 'mc-user-payload.html',
    nodeType: 'mc-user-payload'
  },
  {
    notionUrl: 'https://www.notion.so/redbot/Push-and-Pop-Message-node-ac378a8fc4144cd2be57080f07950fe1',
    nodeFile: 'chatbot-pop-message.html',
    nodeType: 'chatbot-pop-message'
  },
  {
    notionUrl: 'https://www.notion.so/redbot/MC-Queue-2ac745c9314f4f17b61f31b6a517586f',
    nodeFile: 'mc-queue.html',
    nodeType: 'mc-queue'
  }
];

==> node-red-contrib-chatbot-1.2.1.tgz: package/bin/nodes.js <==
module.exports = [
  {
    nodeFile: 'mc-configuration.html',
    nodeType: 'mc-configuration',
    notionUrl: 'https://www.notion.so/redbot/MC-Configuration-node-585cd33e293c40478a47635246742a27'
  },
  {
    nodeFile: 'chatbot-alexa-card.html',
    nodeType: 'chatbot-alexa-card',
    notionUrl: 'https://redbot.notion.site/Alexa-Card-node-fc89c43d79324c8da2f251e26f638246'
  },
  {
    nodeFile: 'mc-graphql.html',
    nodeType: 'mc-graphql',
    notionUrl: 'https://www.notion.so/redbot/MC-GraphQL-node-0dc75116dee9458486e1a4f09fc3f44b'
  },
  {
    notionUrl: 'https://www.notion.so/redbot/Quick-Replies-node-200e9ae1a1fd459baa29c76d6a4025e2',
    nodeFile: 'chatbot-quick-replies.html',
    nodeType: 'chatbot-quick-replies'
  },
  {
    notionUrl: 'https://www.notion.so/redbot/Messenger-Menu-node-c5140a0ab4ae4345a2731f67b92c3e53',
    nodeFile: 'chatbot-messenger-menu.html',
    nodeType: 'chatbot-messenger-menu'
  },
  {
    notionUrl: 'https://www.notion.so/redbot/Messenger-Template-node-ac7d5049cbf64389a2ef6e7fe7f1c392',
    nodeFile: 'chatbot-messenger-template.html',
    nodeType: 'chatbot-messenger-template'
  },
  {
    notionUrl: 'https://www.notion.so/redbot/Document-node-c36fbd8a58574fd0bbf8b0eb04a7d4ae',
    nodeFile: 'chatbot-document.html',
    nodeType: 'chatbot-document'
  },
  {
    notionUrl: 'https://www.notion.so/redbot/Message-node-4ae98c5959704cd993a0cc602a17d68b',
    nodeFile: 'chatbot-message.html',
    nodeType: 'chatbot-message'
  },
  {
    notionUrl: 'https://www.notion.so/redbot/QR-Code-node-94a74e1e16da4c2bbb09a983424354ed',
    nodeFile: 'chatbot-qrcode.html',
    nodeType: 'chatbot-qrcode'
  },
  {
    notionUrl: 'https://www.notion.so/redbot/Rivescript-node-db8481a702b6491093f7ea53d765129e',
    nodeFile: 'chatbot-rivescript.html',
    nodeType: 'chatbot-rivescript'
  },
  {
    notionUrl: 'https://www.notion.so/redbot/Conversation-node-1d90a6e8dfc448d6865c88358c459de2',
    nodeFile: 'chatbot-conversation.html',
    nodeType: 'chatbot-conversation'
  },
  {
    notionUrl: 'https://www.notion.so/redbot/Analytics-node-58dbe17dd23144c6b3ec939a23676b27',
    nodeFile: 'chatbot-analytics.html',
    nodeType: 'chatbot-analytics'
  },
  {
    notionUrl: 'https://www.notion.so/redbot/Debug-node-d768699fac104d0580f14268afa1e53f',
    nodeFile: 'chatbot-debug.html',
    nodeType: 'chatbot-debug'
  },
  {
    notionUrl: 'https://www.notion.so/redbot/Parse-node-face8e9f6efc4369a9ea8527ecd81b1b',
    nodeFile: 'chatbot-parse.html',
    nodeType: 'chatbot-parse'
  },
  {
    notionUrl: 'https://www.notion.so/redbot/Request-node-df78ffeae16d40238f672fbc447ba69e',
    nodeFile: 'chatbot-request.html',
    nodeType: 'chatbot-request'
  },
  {
    notionUrl: 'https://www.notion.so/redbot/Video-node-b359c5ca72494ac6aa5cfff23b1d76fc',
    nodeFile: 'chatbot-video.html',
    nodeType: 'chatbot-video'
  },
  {
    notionUrl: 'https://www.notion.so/redbot/Audio-node-fab15f139525400f8719ff182238eb4c',
    nodeFile: 'chatbot-audio.html',
    nodeType: 'chatbot-audio'
  },
  {
    notionUrl: 'https://www.notion.so/redbot/Voice-node-dbd09f980ed5438e90eb8379ab15594c',
    nodeFile: 'chatbot-voice.html',
    nodeType: 'chatbot-voice'
  },
  {
    notionUrl: 'https://www.notion.so/redbot/Image-node-e4db571720f74584bfa97668c100db43',
    nodeFile: 'chatbot-image.html',
    nodeType: 'chatbot-image'
  },
  {
    notionUrl: 'https://www.notion.so/redbot/Language-node-f5566a5158ad462186414d41766e7056',
    nodeFile: 'chatbot-language.html',
    nodeType: 'chatbot-language'
  },
  {
    notionUrl: 'https://www.notion.so/redbot/Authorized-node-cc9655594def44648f6e02cbf17d9714',
    nodeFile: 'chatbot-authorized.html',
    nodeType: 'chatbot-authorized'
  },
  {
    notionUrl: 'https://www.notion.so/redbot/Log-node-58087595acec4d0593dd7f1375b092d5',
    nodeFile: 'chatbot-log.html',
    nodeType: 'chatbot-log'
  },
  {
    notionUrl: 'https://www.notion.so/redbot/Location-node-60e07c48313c4d0690c0e2ff96fa941f',
    nodeFile: 'chatbot-location.html',
    nodeType: 'chatbot-location'
  },
  {
    notionUrl: 'https://www.notion.so/redbot/Context-node-24a646bff58b4edfb249f1d27384230f',
    nodeFile: 'chatbot-context.html',
    nodeType: 'chatbot-context'
  },
  {
    notionUrl: 'https://www.notion.so/redbot/Telegram-Sticker-node-0e02d900e15e45b39eb4150941d7c9ea',
    nodeFile: 'chatbot-sticker.html',
    nodeType: 'chatbot-sticker'
  },
  {
    notionUrl: 'https://www.notion.so/redbot/Animation-node-5900586541c2444689d3789a7f9f1d77',
    nodeFile: 'chatbot-animation.html',
    nodeType: 'chatbot-animation'
  },
  {
    notionUrl: 'https://www.notion.so/redbot/Telegram-Menu-node-d7159ae828804a8784a639e6cdbdb95d',
    nodeFile: 'chatbot-telegram-menu.html',
    nodeType: 'chatbot-telegram-menu'
  },
  {
    notionUrl: 'https://www.notion.so/redbot/Waiting-node-a020cb205ea249b2a401bdcf8c93ce05',
    nodeFile: 'chatbot-waiting.html',
    nodeType: 'chatbot-waiting'
  },
  {
    notionUrl: 'https://www.notion.so/redbot/Slack-Receiver-node-0e93599cefc44ce7896d5444def135f2',
    nodeFile: 'chatbot-slack-receive.html',
    nodeType: 'chatbot-slack-node'
  },
  {
    notionUrl: 'https://www.notion.so/redbot/Telegram-Receiver-node-4132ce6c78dc4dbbab0fe9eb7e1c3c9b',
    nodeFile: 'chatbot-telegram-receive.html',
    nodeType: 'chatbot-telegram-node'
  },
  {
    notionUrl: 'https://www.notion.so/redbot/Facebook-Receiver-node-c942d43ddc4b4368abb8d00dde650bfa',
    nodeFile: 'chatbot-facebook-receive.html',
    nodeType: 'chatbot-facebook-node'
  },
  {
    notionUrl: 'https://www.notion.so/redbot/Alexa-Receiver-node-82b7744b70fa45e8b786fdd2feae1777',
    nodeFile: 'chatbot-alexa-receive.html',
    nodeType: 'chatbot-alexa-node'
  },
  {
    notionUrl: 'https://www.notion.so/redbot/Twilio-Receiver-node-a0fb82e714fb4674b29e24fa984ca992',
    nodeFile: 'chatbot-twilio-receive.html',
    nodeType: 'chatbot-twilio-node'
  },
  {
    notionUrl: 'https://www.notion.so/redbot/Microsoft-Teams-Receiver-node-7bc640d7770e4542a83de7c8ee0cc246',
    nodeFile: 'chatbot-msteams-receive.html',
    nodeType: 'chatbot-msteams-node'
  },
  {
    notionUrl: 'https://www.notion.so/redbot/Viber-Receiver-node-ae52e68a3aef4483b52b339caa08c62c',
    nodeFile: 'chatbot-viber-receive.html',
    nodeType: 'chatbot-viber-node'
  },
  {
    notionUrl: 'https://www.notion.so/redbot/Switch-node-017a464afeb84225bcb68f8c671808c5',
    nodeFile: 'chatbot-rules.html',
    nodeType: 'chatbot-rules'
  },
  {
    notionUrl: 'https://www.notion.so/redbot/Telegram-Inline-Query-node-ab8e6fd699d544fb852111146edc39db',
    nodeFile: 'chatbot-inline-query.html',
    nodeType: 'chatbot-inline-query'
  },
  {
    notionUrl: 'https://www.notion.so/redbot/Slack-Dialog-node-e620ae50b7ed44c2a24d6876534b3637',
    nodeFile: 'chatbot-dialog.html',
    nodeType: 'chatbot-dialog'
  },
  {
    notionUrl: 'https://www.notion.so/redbot/Rules-node-4113636f565d4ff4af08bc61a644206b',
    nodeFile: 'chatbot-rules.html',
    nodeType: 'chatbot-rules'
  },
  {
    notionUrl: 'https://www.notion.so/redbot/Dialogflow-node-84b9ea66d20743fd9cf45d3de5f17693',
    nodeFile: 'chatbot-dialogflow.html',
    nodeType: 'chatbot-dialogflow'
  },
  {
    notionUrl: 'https://www.notion.so/redbot/Dialogflow-token-node-3663be9a404e4e3a9f3022bb66fe8d1e',
    nodeFile: 'chatbot-dialogflow.html',
    nodeType: 'chatbot-dialogflow-token'
  },
  {
    notionUrl: 'https://www.notion.so/redbot/Invoice-node-15b9b0d320d04b55ad550610112f04dd',
    nodeFile: 'chatbot-invoice.html',
    nodeType: 'chatbot-invoice'
  },
  {
    notionUrl: 'https://www.notion.so/redbot/Telegram-Invoice-Shipping-node-60c4b7025cde40378e87e7c3113907ed',
    nodeFile: 'chatbot-invoice-shipping.html',
    nodeType: 'chatbot-invoice-shipping'
  },
  {
    notionUrl: 'https://www.notion.so/redbot/Context-node-24a646bff58b4edfb249f1d27384230f',
    nodeFile: 'chatbot-context-store.html',
    nodeType: 'chatbot-context-store'
  },
  {
    notionUrl: 'https://www.notion.so/redbot/Keyboard-node-0085af98bd2c4c169d4c7e579c7db316',
    nodeFile: 'chatbot-ask.html',
    nodeType: 'chatbot-ask'
  },
  {
    notionUrl: 'https://www.notion.so/redbot/Buttons-node-b8f3ea33948049cca7b94491061183f4',
    nodeFile: 'chatbot-inline-buttons.html',
    nodeType: 'chatbot-inline-buttons'
  },
  {
    notionUrl: 'https://www.notion.so/redbot/Extend-node-04668c7a415547bc9f34be57dd063db2',
    nodeFile: 'chatbot-extend.html',
    nodeType: 'chatbot-extend'
  },
  {
    notionUrl: 'https://www.notion.so/redbot/Support-table-6cfd957b91f642b5894a76e2b15feb05',
    nodeFile: 'chatbot-support-table.html',
    nodeType: 'chatbot-support-table'
  },
  {
    notionUrl: 'https://www.notion.so/redbot/Alexa-Receiver-node-82b7744b70fa45e8b786fdd2feae1777',
    nodeFile: 'chatbot-alexa-speech.html',
    nodeType: 'chatbot-alexa-speech'
  },
  {
    notionUrl: 'https://www.notion.so/redbot/Alexa-Directive-node-e1e54a8f8c24404f8cd2b01e91b695cf',
    nodeFile: 'chatbot-alexa-directive.html',
    nodeType: 'chatbot-alexa-directive'
  },
  {
    notionUrl: 'https://www.notion.so/redbot/Universal-Connector-node-4c24b378e02c491a90240309b9f349c1',
    nodeFile: 'chatbot-universal-receive.html',
    nodeType: 'chatbot-universal-receive'
  },
  {
    notionUrl: 'https://www.notion.so/redbot/Slack-Blocks-node-deb80b7ba4584671abf117b8772a694a',
    nodeFile: 'chatbot-slack-blocks.html',
    nodeType: 'chatbot-slack-blocks'
  },
  {
    notionUrl: 'https://www.notion.so/redbot/Params-node-d8b27db3949c475184923af913563833',
    nodeFile: 'chatbot-params.html',
    nodeType: 'chatbot-params'
  },
  {
    notionUrl: 'https://www.notion.so/redbot/NLPjs-Train-77f9e99250274f12b37b67fd3854f831',
    nodeFile: 'chatbot-nlp-train.html',
    nodeType: 'chatbot-nlpjs-train'
  },
  {
    notionUrl: 'https://www.notion.so/redbot/NLPjs-Entity-f73d1e0200804467b8f03e077584fb16',
    nodeFile: 'chatbot-nlp-entity.html',
    nodeType: 'chatbot-nlpjs-entity'
  },
  {
    notionUrl: 'https://www.notion.so/redbot/NLPjs-Intent-node-c91af0a6fde74dc5b575aa7230565ba8',
    nodeFile: 'chatbot-nlp-intent.html',
    nodeType: 'chatbot-nlpjs-intent'
  },
  {
    notionUrl: 'https://www.notion.so/redbot/NLPjs-Save-4f99d9bfe1ee4683acbee70c02eb24d2',
    nodeFile: 'chatbot-nlp-save.html',
    nodeType: 'chatbot-nlpjs-save'
  },
  {
    notionUrl: 'https://www.notion.so/redbot/NLPjs-Load-fc80ea9420fe492389109c610ee7f812',
    nodeFile: 'chatbot-nlp-load.html',
    nodeType: 'chatbot-nlpjs-load'
  },
  {
    notionUrl: 'https://www.notion.so/redbot/NLPjs-Process-bbc3deb2d39a4b338fc6515eee337cd4',
    nodeFile: 'chatbot-nlp.html',
    nodeType: 'chatbot-nlpjs'
  },
  {
    notionUrl: 'https://www.notion.so/redbot/MC-User-Payload-dc8260a96abb430c856bfc2deb388238',
    nodeFile: 'mc-user-payload.html',
    nodeType: 'mc-user-payload'
  },
  {
    notionUrl: 'https://www.notion.so/redbot/Push-and-Pop-Message-node-ac378a8fc4144cd2be57080f07950fe1',
    nodeFile: 'chatbot-pop-message.html',
    nodeType: 'chatbot-pop-message'
  },
  {
    notionUrl: 'https://www.notion.so/redbot/MC-Queue-2ac745c9314f4f17b61f31b6a517586f',
    nodeFile: 'mc-queue.html',
    nodeType: 'mc-queue'
  },
  {
    notionUrl: 'https://www.notion.so/redbot/Whatsapp-Template-2cf0f96ed14b4f72b3d4a8cee58bc2b0',
    nodeFile: 'chatbot-whatsapp-template.html',
    nodeType: 'chatbot-whatsapp-template'
  }
];
